==> fltk-docs-1.3.8-2-aarch64.pkg.tar.xz: usr/share/doc/fltk/html/navtreeindex16.js <==
var NAVTREEINDEX16 =
{
"structFl__Multi__Label.html#af72aa419e40c7a64116ea19f4fee4b98":[4,0,83,0],
"structFl__Paged__Device_1_1page__format.html":[4,0,91,0],
"structFl__Paged__Device_1_1page__format.html#a40cbb3d64e0d9b1b94c6f4b430b1a84c":[4,0,91,0,2],
"structFl__Paged__Device_1_1page__format.html#a8f0de961877d6c60870ff7d5e3aae720":[4,0,91,0,0],
"structFl__Paged__Device_1_1page__format.html#ab281b2d2443be0bb9f7fbe59c87346bd":[4,0,91,0,1],
"structFl__Preferences_1_1Entry.html":[4,0,101,0],
"structFl__Scroll_1_1Fl__Region__LRTB.html":[4,0,114,0],
"structFl__Scroll_1_1Fl__Region__LRTB.html#a30c172f8d46c0dd3ef984f8bf3f4bfae":[4,0,114,0,2],
"structFl__Scroll_1_1Fl__Region__LRTB.html#a4b025c0301af8bad486e00db5c808f16":[4,0,114,0,0],
"structFl__Scroll_1_1Fl__Region__LRTB.html#a639c8c025b30d5bec5b19880eb747724":[4,0,114,0,1],
"structFl__Scroll_1_1Fl__Region__LRTB.html#a74f844879de21902233eca3c2d244d01":[4,0,114,0,3],
"structFl__Scroll_1_1Fl__Region__XYWH.html":[4,0,114,1],
"structFl__Scroll_1_1Fl__Scrollbar__Data.html":[4,0,114,2],
"structFl__Scroll_1_1Fl__Scrollbar__Data.html#a2fa8356d208bf3a3a1b3ed3f74979f99":[4,0,114,2,1],
"structFl__Scroll_1_1Fl__Scrollbar__Data.html#a67e8864b65f06ad257ed30d0cdf7150c":[4,0,114,2,3],
"structFl__Scroll_1_1Fl__Scrollbar__Data.html#a6baf6f1401347ed9fee7e5cf2aded7de":[4,0,114,2,2],
"structFl__Scroll_1_1Fl__Scrollbar__Data.html#ad54a2f225b7ce1298e947338357b9a83":[4,0,114,2,0],
"structFl__Scroll_1_1ScrollInfo.html":[4,0,114,3],
"structFl__Scroll_1_1ScrollInfo.html#a11df1f6333d826848e69a0ddfd8e209b":[4,0,114,3,0],
"structFl__Scroll_1_1ScrollInfo.html#a4057566bd6430cadf21f9dcce9cb84a7":[4,0,114,3,5],
"structFl__Scroll_1_1ScrollInfo.html#a644cbf16946465c277355fcbb3e3d056":[4,0,114,3,1],
"structFl__Scroll_1_1ScrollInfo.html#a65d441a8beb662fa7fa88dfce78520e5":[4,0,114,3,6],
"structFl__Scroll_1_1ScrollInfo.html#a6b1b152acb5a509d8a701f0547db1648":[4,0,114,3,3],
"structFl__Scroll_1_1ScrollInfo.html#a9f30a1471199feee650000708b4b2451":[4,0,114,3,2],
"structFl__Scroll_1_1ScrollInfo.html#aae9aa002dce20fefd0b76831cd431f0c":[4,0,114,3,4],
"structFl__Scroll_1_1ScrollInfo.html#ad7e2a81ba4a7950257f0649c1c6b4c29":[4,0,114,3,7],
"structFl__Text__Display_1_1Style__Table__Entry.html":[4,0,130,0],
"structFl__Text__Display_1_1Style__Table__Entry.html#a300e0718e340a459683d0cc89373a71e":[4,0,130,0,1],
"structFl__Text__Display_1_1Style__Table__Entry.html#a9be7c26469179361896bdc58474a90fe":[4,0,130,0,3],
"structFl__Text__Display_1_1Style__Table__Entry.html#aa5b90f60865debffdb3ed09a6f77c479":[4,0,130,0,2],
"structFl__Text__Display_1_1Style__Table__Entry.html#aa67bded6858f732de5c205ffa0a564ba":[4,0,130,0,0],
"structFl__Text__Editor_1_1Key__Binding.html":[4,0,131,0],
"structFl__Text__Editor_1_1Key__Binding.html#a157084ba4caf5710c8907c0ff5612579":[4,0,131,0,1],
"structFl__Text__Editor_1_1Key__Binding.html#a3af824707ebdf703f9d54c03f528ebc1":[4,0,131,0,0],
"structFl__Text__Editor_1_1Key__Binding.html#a8b1a0963bac88fdfbcca38d8d079f5ae":[4,0,131,0,3],
"structFl__Text__Editor_1_1Key__Binding.html#ab9b34380e32d84f35c000e29250349c9":[4,0,131,0,2],
"structFl__Window_1_1shape__data__type.html":[4,0,148,0],
"structFl__Window_1_1shape__data__type.html#a23c9b0905fdb1caad79ae32b4305b1d1":[4,0,148,0,0],
"structFl__Window_1_1shape__data__type.html#a45247ac6945de267bd2c532ccd3032d0":[4,0,148,0,3],
"structFl__Window_1_1shape__data__type.html#a87595b84e4b90a0433f604a7ef6170fb":[4,0,148,0,2],
"structFl__Window_1_1shape__data__type.html#aa2192e27474e3d8bcae2ddaebc8e0090":[4,0,148,0,1],
"structFl__XColor.html":[4,0,151],
"subclassing.html":[0,7],
"subclassing.html#subclassing_composite":[0,7,7],
"subclassing.html#subclassing_constructor":[0,7,2],
"subclassing.html#subclassing_cutnpaste":[0,7,8],
"subclassing.html#subclassing_dragndrop":[0,7,9],
"subclassing.html#subclassing_drawing":[0,7,5],
"subclassing.html#subclassing_events":[0,7,4],
"subclassing.html#subclassing_fl_widget":[0,7,1],
"subclassing.html#subclassing_fl_window":[0,7,10],
"subclassing.html#subclassing_protected":[0,7,3],
"subclassing.html#subclassing_resizing":[0,7,6],
"subclassing.html#subclassing_subclassing":[0,7,0],
"symbol___8h_source.html":[5,0,0,1,0,0,3],
"tatar__cyr_8h_source.html":[5,0,0,1,0,1,36],
"tcvn_8h_source.html":[5,0,0,1,0,1,37],
"tis620_8h_source.html":[5,0,0,1,0,1,38],
"todo.html":[1],
"ucs2be_8h_source.html":[5,0,0,1,0,1,39],
"unicode.html":[0,11],
"unicode.html#unicode_about":[0,11,0],
"unicode.html#unicode_fltk_calls":[0,11,3],
"unicode.html#unicode_illegals":[0,11,2],
"unicode.html#unicode_in_fltk":[0,11,1],
"unicode.html#unicode_system_calls":[0,11,4],
"utf8_8h_source.html":[5,0,0,1,0,1,40],
"viscii_8h_source.html":[5,0,0,1,0,1,41],
"win32_8H_source.html":[5,0,0,0,142],
"x_8H_source.html":[5,0,0,0,143]
};

==> fltk-docs-1.3.9-1-aarch64.pkg.tar.xz: usr/share/doc/fltk/html/navtreeindex16.js <==
var NAVTREEINDEX16 =
{
"structFl__Menu__Item.html#af4f5dbf86abb2d5158984a05368e923a":[4,0,80,40],
"structFl__Menu__Item.html#af9a1be4dfffcff2ba77cfccfec655588":[4,0,80,3],
"structFl__Multi__Label.html":[4,0,83],
"structFl__Multi__Label.html#a09c69b2d4b971cfb85396795a643f83a":[4,0,83,4],
"structFl__Multi__Label.html#a2fb8179ce00ac149aec20a4f659eb2f8":[4,0,83,3],
"structFl__Multi__Label.html#a50c609957da3af418a48cfea9fbb632a":[4,0,83,1],
"structFl__Multi__Label.html#a6b4edb800cb21d45cd137ecd8a8d66ef":[4,0,83,2],
"structFl__Multi__Label.html#a8a52fb11250265e3132caaa36a24bacf":[4,0,83,5],
"structFl__Multi__Label.html#af72aa419e40c7a64116ea19f4fee4b98":[4,0,83,0],
"structFl__Paged__Device_1_1page__format.html":[4,0,91,0],
"structFl__Paged__Device_1_1page__format.html#a40cbb3d64e0d9b1b94c6f4b430b1a84c":[4,0,91,0,2],
"structFl__Paged__Device_1_1page__format.html#a8f0de961877d6c60870ff7d5e3aae720":[4,0,91,0,0],
"structFl__Paged__Device_1_1page__format.html#ab281b2d2443be0bb9f7fbe59c87346bd":[4,0,91,0,1],
"structFl__Preferences_1_1Entry.html":[4,0,101,0],
"structFl__Scroll_1_1Fl__Region__LRTB.html":[4,0,114,0],
"structFl__Scroll_1_1Fl__Region__LRTB.html#a30c172f8d46c0dd3ef984f8bf3f4bfae":[4,0,114,0,2],
"structFl__Scroll_1_1Fl__Region__LRTB.html#a4b025c0301af8bad486e00db5c808f16":[4,0,114,0,0],
"structFl__Scroll_1_1Fl__Region__LRTB.html#a639c8c025b30d5bec5b19880eb747724":[4,0,114,0,1],
"structFl__Scroll_1_1Fl__Region__LRTB.html#a74f844879de21902233eca3c2d244d01":[4,0,114,0,3],
"structFl__Scroll_1_1Fl__Region__XYWH.html":[4,0,114,1],
"structFl__Scroll_1_1Fl__Scrollbar__Data.html":[4,0,114,2],
"structFl__Scroll_1_1Fl__Scrollbar__Data.html#a2fa8356d208bf3a3a1b3ed3f74979f99":[4,0,114,2,1],
"structFl__Scroll_1_1Fl__Scrollbar__Data.html#a67e8864b65f06ad257ed30d0cdf7150c":[4,0,114,2,3],
"structFl__Scroll_1_1Fl__Scrollbar__Data.html#a6baf6f1401347ed9fee7e5cf2aded7de":[4,0,114,2,2],
"structFl__Scroll_1_1Fl__Scrollbar__Data.html#ad54a2f225b7ce1298e947338357b9a83":[4,0,114,2,0],
"structFl__Scroll_1_1ScrollInfo.html":[4,0,114,3],
"structFl__Scroll_1_1ScrollInfo.html#a11df1f6333d826848e69a0ddfd8e209b":[4,0,114,3,0],
"structFl__Scroll_1_1ScrollInfo.html#a4057566bd6430cadf21f9dcce9cb84a7":[4,0,114,3,5],
"structFl__Scroll_1_1ScrollInfo.html#a644cbf16946465c277355fcbb3e3d056":[4,0,114,3,1],
"structFl__Scroll_1_1ScrollInfo.html#a65d441a8beb662fa7fa88dfce78520e5":[4,0,114,3,6],
"structFl__Scroll_1_1ScrollInfo.html#a6b1b152acb5a509d8a701f0547db1648":[4,0,114,3,3],
"structFl__Scroll_1_1ScrollInfo.html#a9f30a1471199feee650000708b4b2451":[4,0,114,3,2],
"structFl__Scroll_1_1ScrollInfo.html#aae9aa002dce20fefd0b76831cd431f0c":[4,0,114,3,4],
"structFl__Scroll_1_1ScrollInfo.html#ad7e2a81ba4a7950257f0649c1c6b4c29":[4,0,114,3,7],
"structFl__Text__Display_1_1Style__Table__Entry.html":[4,0,130,0],
"structFl__Text__Display_1_1Style__Table__Entry.html#a300e0718e340a459683d0cc89373a71e":[4,0,130,0,1],
"structFl__Text__Display_1_1Style__Table__Entry.html#a9be7c26469179361896bdc58474a90fe":[4,0,130,0,3],
"structFl__Text__Display_1_1Style__Table__Entry.html#aa5b90f60865debffdb3ed09a6f77c479":[4,0,130,0,2],
"structFl__Text__Display_1_1Style__Table__Entry.html#aa67bded6858f732de5c205ffa0a564ba":[4,0,130,0,0],
"structFl__Text__Editor_1_1Key__Binding.html":[4,0,131,0],
"structFl__Text__Editor_1_1Key__Binding.html#a157084ba4caf5710c8907c0ff5612579":[4,0,131,0,1],
"structFl__Text__Editor_1_1Key__Binding.html#a3af824707ebdf703f9d54c03f528ebc1":[4,0,131,0,0],
"structFl__Text__Editor_1_1Key__Binding.html#a8b1a0963bac88fdfbcca38d8d079f5ae":[4,0,131,0,3],
"structFl__Text__Editor_1_1Key__Binding.html#ab9b34380e32d84f35c000e29250349c9":[4,0,131,0,2],
"structFl__Window_1_1shape__data__type.html":[4,0,148,0],
"structFl__Window_1_1shape__data__type.html#a23c9b0905fdb1caad79ae32b4305b1d1":[4,0,148,0,0],
"structFl__Window_1_1shape__data__type.html#a45247ac6945de267bd2c532ccd3032d0":[4,0,148,0,3],
"structFl__Window_1_1shape__data__type.html#a87595b84e4b90a0433f604a7ef6170fb":[4,0,148,0,2],
"structFl__Window_1_1shape__data__type.html#aa2192e27474e3d8bcae2ddaebc8e0090":[4,0,148,0,1],
"structFl__XColor.html":[4,0,151],
"subclassing.html":[0,7],
"subclassing.html#subclassing_composite":[0,7,7],
"subclassing.html#subclassing_constructor":[0,7,2],
"subclassing.html#subclassing_cutnpaste":[0,7,8],
"subclassing.html#subclassing_dragndrop":[0,7,9],
"subclassing.html#subclassing_drawing":[0,7,5],
"subclassing.html#subclassing_events":[0,7,4],
"subclassing.html#subclassing_fl_widget":[0,7,1],
"subclassing.html#subclassing_fl_window":[0,7,10],
"subclassing.html#subclassing_protected":[0,7,3],
"subclassing.html#subclassing_resizing":[0,7,6],
"subclassing.html#subclassing_subclassing":[0,7,0],
"symbol___8h_source.html":[5,0,0,1,0,0,3],
"tatar__cyr_8h_source.html":[5,0,0,1,0,1,36],
"tcvn_8h_source.html":[5,0,0,1,0,1,37],
"tis620_8h_source.html":[5,0,0,1,0,1,38],
"todo.html":[1],
"topics.html":[3],
"ucs2be_8h_source.html":[5,0,0,1,0,1,39],
"ucs2fontmap_8c_source.html":[5,0,0,1,0,4],
"unicode.html":[0,11],
"unicode.html#unicode_about":[0,11,0],
"unicode.html#unicode_fltk_calls":[0,11,3],
"unicode.html#unicode_illegals":[0,11,2],
"unicode.html#unicode_in_fltk":[0,11,1],
"unicode.html#unicode_system_calls":[0,11,4],
"utf8Utils_8c_source.html":[5,0,0,1,0,5],
"utf8_8h_source.html":[5,0,0,1,0,1,40],
"viscii_8h_source.html":[5,0,0,1,0,1,41],
"win32_8H_source.html":[5,0,0,0,142],
"x_8H_source.html":[5,0,0,0,143]
};
